@@ -7,3 +7,7 @@ var orig_name = doc.name;
 alert(orig_name);
 """
 app.doJavaScript(jsx)
+
+
+# Print name of current active document.
+print(app.doJavaScript("app.activeDocument.name"))
